==> kpl-3.0.tar.bz2: kpl-3.0/kpl/funcdlg.h <==
/***************************************************************************
                          funcdlg.h  -  description
                             -------------------

    This file is a part of kpl - a program for graphical presentation of
    data sets and functions.

    begin                : Sun Apr 25 1999
    copyright            : (C) 2002 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef FUNCDLG_H
#define FUNCDLG_H

#include <kdialogbase.h>

class KplDoc;
class KColorButton;
class QLineEdit;
class QListBox;
class FunItem;
class ParFunItem;
class KplDoubleEdit;
class KplSpinBox;

/**
  * Function settings dialog class. Provides a dialog for the settings
  * of an ordinary function.
  * @author Werner Stille
  */
class FuncDlg : public KDialogBase
{
  Q_OBJECT
public:
  /**
   * Constructor.
   * @param parent pointer to parent widget.
   * @param model pointer to KplDoc model object.
   * @param fd pointer to function object.
   */
  FuncDlg(QWidget* parent, KplDoc* model, FunItem* fd);
  /** Destructor. */
  ~FuncDlg();
  /**
   * Opens a function selection dialog.
   * @param parent parent widget.
   * @param name QLineEdit widget displaying the library filename.
   * @param func QLineEdit widget to display the function name.
   */
  static void getFunc(QWidget* parent, QLineEdit* name, QLineEdit* func);

protected:
  /**
   * Copies settings to temporary function object.
   * @return false for error.
   */
  bool getTemp();
  /**
   * Copies settings to function object.
   * @param accept true for leaving the dialog, false for applying.
   * @return false for error.
   */
  void getValues(bool accept);
  KplDoc* m;
  FunItem *fd, *fdt;
  QLineEdit *fileName, *func;
  KplDoubleEdit *exMin, *exMax, *exStep, *efx, *efy;
  KplSpinBox *symb, *eRelSize;
  KColorButton* colData;

protected slots:
  /** Displays the dialog for selection of a library file to load. */
  void slotFile();
  /** Displays the dialog for selection of a function. */
  void slotFunc();
  /** Displays the dialog for selection of a parameter file to read. */
  void slotGetParameter();
  /** Displays the dialog for parameter editing. */
  void slotEditParameter();
  /** Displays the dialog for selection of a parameter file to save. */
  void slotSaveParameter();
  /** Saves function value table into a data file. */
  void slotUser1();
  /** Applies settings and leaves the dialog. */
  void slotOk();
  /** Applies settings without leaving the dialog. */
  void slotApply();
  /** Displays help for the function settings dialog. */
  void slotHelp2();
};

/**
  * Parametric function settings dialog class. Provides a dialog for the settings
  * of parametric functions.
  * @author Werner Stille
  */
class ParFuncDlg : public KDialogBase
{
  Q_OBJECT
public:
  /**
   * Constructor.
   * @param parent pointer to parent widget.
   * @param model pointer to KplDoc model object.
   * @param fd pointer to parametric function object.
   */
  ParFuncDlg(QWidget* parent, KplDoc* model, ParFunItem* fd);
  /** Destructor. */
  ~ParFuncDlg();

protected:
  /**
   * Copies settings to temporary parametric function object.
   * @return false for error.
   */
  bool getTemp();
  /**
   * Copies settings to parametric function object.
   * @param accept true for leaving the dialog, false for applying.
   */
  void getValues(bool accept);
  KplDoc* m;
  ParFunItem *fd, *fdt;
  QLineEdit *fileNamex, *funcx, *fileNamey, *funcy;
  KplDoubleEdit *etMin, *etMax, *etStep, *efx, *efy;
  KplSpinBox *symb, *eRelSize;
  KColorButton* colData;

protected slots:
  /** Displays the dialog for selection of a library file to load for the x axis. */
  void slotFilex();
  /** Displays the dialog for selection of a library file to load for the y axis. */
  void slotFiley();
  /** Displays the dialog for selection of a function for the x axis. */
  void slotFuncx();
  /** Displays the dialog for selection of a function for the y axis. */
  void slotFuncy();
  /** Displays the dialog for selection of a parameter file to read for the x axis function. */
  void slotGetParameterx();
  /** Displays the dialog for selection of a parameter file to read for the y axis function. */
  void slotGetParametery();
  /** Displays the dialog for parameter editing for the x axis function. */
  void slotEditParameterx();
  /** Displays the dialog for parameter editing for the y axis function. */
  void slotEditParametery();
  /** Displays the dialog for selection of a parameter file to save for the x axis function. */
  void slotSaveParameterx();
  /** Displays the dialog for selection of a parameter file to save for the y axis function. */
  void slotSaveParametery();
  /** Saves function value table into a data file. */
  void slotUser1();
  /** Applies settings and leaves the dialog. */
  void slotOk();
  /** Applies settings without leaving the dialog. */
  void slotApply();
  /** Displays help for the parametric function settings dialog. */
  void slotHelp2();
};

#endif

==> kpl-3.1.tar.bz2: kpl-3.1/kpl/funcdlg.h <==
/***************************************************************************
                          funcdlg.h  -  description
                             -------------------

    This file is a part of kpl - a program for graphical presentation of
    data sets and functions.

    begin                : Sun Apr 25 1999
    copyright            : (C) 2003 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef FUNCDLG_H
#define FUNCDLG_H

#include <kdialogbase.h>

class KplDoc;
class KColorButton;
class QLineEdit;
class QListBox;
class FunItem;
class ParFunItem;
class KplDoubleEdit;
class KplSpinBox;

/**
  * Function settings dialog class. Provides a dialog for the settings
  * of an ordinary function.
  * @author Werner Stille
  */
class FuncDlg : public KDialogBase
{
  Q_OBJECT
public:
  /**
   * Constructor.
   * @param parent pointer to parent widget.
   * @param model pointer to KplDoc model object.
   * @param fd pointer to function object.
   */
  FuncDlg(QWidget* parent, KplDoc* model, FunItem* fd);
  /** Destructor. */
  ~FuncDlg();
  /**
   * Opens a function selection dialog.
   * @param parent parent widget.
   * @param name QLineEdit widget displaying the library filename.
   * @param func QLineEdit widget to display the function name.
   * @param d3 true in case of a 3D function.
   */
  static void getFunc(QWidget* parent, QLineEdit* name, QLineEdit* func,
                      bool d3 = false);

protected:
  /**
   * Copies settings to temporary function object.
   * @return false for error.
   */
  bool getTemp();
  /**
   * Copies settings to function object.
   * @param accept true for leaving the dialog, false for applying.
   * @return false for error.
   */
  void getValues(bool accept);
  KplDoc* m;
  FunItem *fd, *fdt;
  QLineEdit *fileName, *func;
  KplDoubleEdit *exMin, *exMax, *exStep, *efx, *efy;
  KplSpinBox *symb, *eRelSize;
  KColorButton* colData;

protected slots:
  /** Displays the dialog for selection of a library file to load. */
  void slotFile();
  /** Displays the dialog for selection of a function. */
  void slotFunc();
  /** Displays the dialog for selection of a parameter file to read. */
  void slotGetParameter();
  /** Displays the dialog for parameter editing. */
  void slotEditParameter();
  /** Displays the dialog for selection of a parameter file to save. */
  void slotSaveParameter();
  /** Saves function value table into a data file. */
  virtual void slotUser1();
  /** Shows root finding dialog. */
  virtual void slotUser2();
  /** Applies settings and leaves the dialog. */
  virtual void slotOk();
  /** Applies settings without leaving the dialog. */
  virtual void slotApply();
};

/**
  * Parametric function settings dialog class. Provides a dialog for the settings
  * of parametric functions.
  * @author Werner Stille
  */
class ParFuncDlg : public KDialogBase
{
  Q_OBJECT
public:
  /**
   * Constructor.
   * @param parent pointer to parent widget.
   * @param model pointer to KplDoc model object.
   * @param fd pointer to parametric function object.
   */
  ParFuncDlg(QWidget* parent, KplDoc* model, ParFunItem* fd);
  /** Destructor. */
  ~ParFuncDlg();

protected:
  /**
   * Copies settings to temporary parametric function object.
   * @return false for error.
   */
  bool getTemp();
  /**
   * Copies settings to parametric function object.
   * @param accept true for leaving the dialog, false for applying.
   */
  void getValues(bool accept);
  KplDoc* m;
  ParFunItem *fd, *fdt;
  QLineEdit *fileNamex, *funcx, *fileNamey, *funcy;
  KplDoubleEdit *etMin, *etMax, *etStep, *efx, *efy;
  KplSpinBox *symb, *eRelSize;
  KColorButton* colData;

protected slots:
  /** Displays the dialog for selection of a library file to load for the x axis. */
  void slotFilex();
  /** Displays the dialog for selection of a library file to load for the y axis. */
  void slotFiley();
  /** Displays the dialog for selection of a function for the x axis. */
  void slotFuncx();
  /** Displays the dialog for selection of a function for the y axis. */
  void slotFuncy();
  /** Displays the dialog for selection of a parameter file to read for the x axis function. */
  void slotGetParameterx();
  /** Displays the dialog for selection of a parameter file to read for the y axis function. */
  void slotGetParametery();
  /** Displays the dialog for parameter editing for the x axis function. */
  void slotEditParameterx();
  /** Displays the dialog for parameter editing for the y axis function. */
  void slotEditParametery();
  /** Displays the dialog for selection of a parameter file to save for the x axis function. */
  void slotSaveParameterx();
  /** Displays the dialog for selection of a parameter file to save for the y axis function. */
  void slotSaveParametery();
  /** Saves function value table into a data file. */
  virtual void slotUser1();
  /** Applies settings and leaves the dialog. */
  virtual void slotOk();
  /** Applies settings without leaving the dialog. */
  virtual void slotApply();
};

#endif
